package com.evobms.project.bms.service.impl;

import java.util.List;
import com.evobms.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.evobms.project.bms.mapper.BmsSopDataMapper;
import com.evobms.project.bms.domain.BmsSopData;
import com.evobms.project.bms.service.IBmsSopDataService;

/**
 * BMS功率能力(SOP)数据Service业务层处理
 * 
 * @author tzy
 * @date 2026-02-23
 */
@Service
public class BmsSopDataServiceImpl extends ServiceImpl<BmsSopDataMapper, BmsSopData> implements IBmsSopDataService 
{
    @Autowired
    private BmsSopDataMapper bmsSopDataMapper;

    /**
     * 查询BMS功率能力(SOP)数据
     * 
     * @param id BMS功率能力(SOP)数据主键
     * @return BMS功率能力(SOP)数据
     */
    @Override
    public BmsSopData selectBmsSopDataById(Long id)
    {
        return bmsSopDataMapper.selectBmsSopDataById(id);
    }

    /**
     * 查询BMS功率能力(SOP)数据列表
     * 
     * @param bmsSopData BMS功率能力(SOP)数据
     * @return BMS功率能力(SOP)数据
     */
    @Override
    public List<BmsSopData> selectBmsSopDataList(BmsSopData bmsSopData)
    {
        return bmsSopDataMapper.selectBmsSopDataList(bmsSopData);
    }

    /**
     * 新增BMS功率能力(SOP)数据
     * 
     * @param bmsSopData BMS功率能力(SOP)数据
     * @return 结果
     */
    @Override
    public int insertBmsSopData(BmsSopData bmsSopData)
    {
        bmsSopData.setCreateTime(DateUtils.getNowDate());
        return bmsSopDataMapper.insertBmsSopData(bmsSopData);
    }

    /**
     * 修改BMS功率能力(SOP)数据
     * 
     * @param bmsSopData BMS功率能力(SOP)数据
     * @return 结果
     */
    @Override
    public int updateBmsSopData(BmsSopData bmsSopData)
    {
        bmsSopData.setUpdateTime(DateUtils.getNowDate());
        return bmsSopDataMapper.updateBmsSopData(bmsSopData);
    }

    /**
     * 批量删除BMS功率能力(SOP)数据
     * 
     * @param ids 需要删除的BMS功率能力(SOP)数据主键
     * @return 结果
     */
    @Override
    public int deleteBmsSopDataByIds(Long[] ids)
    {
        return bmsSopDataMapper.deleteBmsSopDataByIds(ids);
    }

    /**
     * 删除BMS功率能力(SOP)数据信息
     * 
     * @param id BMS功率能力(SOP)数据主键
     * @return 结果
     */
    @Override
    public int deleteBmsSopDataById(Long id)
    {
        return bmsSopDataMapper.deleteBmsSopDataById(id);
    }
}
