package com.evobms.project.bms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.evobms.framework.aspectj.lang.annotation.Log;
import com.evobms.framework.aspectj.lang.enums.BusinessType;
import com.evobms.project.bms.domain.BmsSopData;
import com.evobms.project.bms.service.IBmsSopDataService;
import com.evobms.framework.web.controller.BaseController;
import com.evobms.framework.web.domain.AjaxResult;
import com.evobms.common.utils.poi.ExcelUtil;
import com.evobms.framework.web.page.TableDataInfo;

/**
 * BMS功率能力(SOP)数据Controller
 *
 * @author tzy
 * @date 2026-02-23
 */
@RestController
@RequestMapping("/bms/sop/data")
public class BmsSopDataController extends BaseController
{
    @Autowired
    private IBmsSopDataService bmsSopDataService;

    /**
     * 查询BMS功率能力(SOP)数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:list')")
    @GetMapping("/list")
    public TableDataInfo list(BmsSopData bmsSopData)
    {
        startPage();
        List<BmsSopData> list = bmsSopDataService.selectBmsSopDataList(bmsSopData);
        return getDataTable(list);
    }

    /**
     * 导出BMS功率能力(SOP)数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:export')")
    @Log(title = "BMS功率能力(SOP)数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsSopData bmsSopData)
    {
        List<BmsSopData> list = bmsSopDataService.selectBmsSopDataList(bmsSopData);
        ExcelUtil<BmsSopData> util = new ExcelUtil<BmsSopData>(BmsSopData.class);
        util.exportExcel(response, list, "BMS功率能力(SOP)数据数据");
    }

    /**
     * 获取BMS功率能力(SOP)数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('bms:data:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmsSopDataService.selectBmsSopDataById(id));
    }

    /**
     * 新增BMS功率能力(SOP)数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:add')")
    @Log(title = "BMS功率能力(SOP)数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsSopData bmsSopData)
    {
        return toAjax(bmsSopDataService.insertBmsSopData(bmsSopData));
    }

    /**
     * 修改BMS功率能力(SOP)数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:edit')")
    @Log(title = "BMS功率能力(SOP)数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsSopData bmsSopData)
    {
        return toAjax(bmsSopDataService.updateBmsSopData(bmsSopData));
    }

    /**
     * 删除BMS功率能力(SOP)数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:remove')")
    @Log(title = "BMS功率能力(SOP)数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmsSopDataService.deleteBmsSopDataByIds(ids));
    }
}
